def display_data(data):
    print("Latest Earthquake Information in Indonesia")
    # To handle error/empty data
    if data is None:
        print("Can't find the latest earthquake data")
        return
    for key, value in data.items():
        if type(value) == dict:
            print(f"    {key}:")
            for x, y in value.items():
                print(f"        {x}: {y}")
        else:
            print(f"    {key}: {value}")


import requests
from bs4 import BeautifulSoup


def extract_data():
    # Get HTML content from website/url
    try:
        content = requests.get('https://bmkg.go.id')
    except requests.RequestException as e:
        print(f"Error: {str(e)}")
        return None

    # If website/url working correctly, parse content using beautifulsoup4
    if content.status_code == 200:
        soup = BeautifulSoup(content.text, 'html.parser')

        # Get ul-list which provide earthquake details
        result = soup.find('div', {'class': 'gempabumi-detail'})
        result = result.findChildren('li')

        # Declare earthquake variables
        datetime = None
        magnitude = None
        depth = None
        coordinate = None
        location = None
        condition = None

        # Looping result and assign value to earthquake variables
        for i, res in enumerate(result):
            if i == 0:
                datetime = res.text
            elif i == 1:
                magnitude = res.text
            elif i == 2:
                depth = res.text
            elif i == 3:
                coordinate = res.text
            elif i == 4:
                location = res.text
            elif i == 5:
                condition = res.text
            else:
                break

        # Create dictionary of earthquake variables
        res_dict = {
            'datetime': {
                'date': datetime.split(', ')[0],
                'time': datetime.split(', ')[1]
            },
            'magnitude': magnitude,
            'depth': depth,
            'coordinate': {
                'lat': coordinate.split(' - ')[0],
                'long': coordinate.split(' - ')[1]
            },
            'location': location,
            'condition': condition
        }

        # Return dictionary
        return res_dict
    else:
        print("Server error")
        return None




import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_descriptions = fh.read()

setuptools.setup(
    name="bmkgquake",
    version="0.1",
    author="Destin Erika Nawang Budiarti",
    author_email="destinerikanb@gmail.com",
    description="This package provides a simple way to retrieve latest earthquake data in Indonesia from the official website of the Indonesian Meteorology, Climatology, and Geophysics Agency (BMKG)",
    long_description=long_descriptions,
    long_description_content_type='text/markdown',
    url="https://github.com/destin-stack/BMKGquake-fetcher-package",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Operating System :: OS Independent",
        "Development Status :: 5 - Production/Stable"
    ],
    packages=setuptools.find_packages(),
    python_requires=">=3.6",
)